###########################################################################
#
#   sdl.mak
#
#   SDL-specific makefile
#
#   Copyright (c) 1996-2007, Nicola Salmoria and the MAME Team.
#   Visit http://mamedev.org for licensing and usage restrictions.
#
#   SDLMAME by Olivier Galibert and R. Belmont 
#
###########################################################################

#-------------------------------------------------
# OSD core library
#-------------------------------------------------

OSDCOREOBJS = \
	$(OBJ)/$(MAMEOS)/strconv.o	\
	$(OBJ)/$(MAMEOS)/sdlfile.o  	\
	$(OBJ)/$(MAMEOS)/sdldir.o	\
	$(OBJ)/$(MAMEOS)/sdltime.o	\
	$(OBJ)/$(MAMEOS)/sdlwork.o	\

OSOBJS =  $(OBJ)/sdl/config.o $(OBJ)/sdl/sdlmain.o \
	$(OBJ)/sdl/fronthlp.o $(OBJ)/sdl/input.o \
	$(OBJ)/sdl/sound.o $(OBJ)/sdl/misc.o $(OBJ)/sdl/video.o \
	$(OBJ)/sdl/drawsdl.o $(OBJ)/sdl/window.o $(OBJ)/sdl/keybled.o \
	$(OBJ)/sdl/scale2x.o

# add the debugger includes
CFLAGS += -Isrc/debug

# add the prefix file
CFLAGS += -include src/$(MAMEOS)/sdlprefix.h

# Linux: add the necessary libaries
ifeq ($(SUBARCH),linux)

# some distros (notably Slackware) still put important things in /usr/X11R6/lib
LIBS += `sdl-config --libs` -L/usr/X11R6/lib -lGL -lXinerama

# the new debugger relies on GTK+ in addition to the base SDLMAME needs
ifdef DEBUG
OSOBJS += $(OBJ)/sdl/debugwin.o $(OBJ)/sdl/dview.o $(OBJ)/sdl/debug-sup.o $(OBJ)/sdl/debug-intf.o
CFLAGS += `pkg-config --cflags gtk+-2.0` `pkg-config --cflags gconf-2.0` 
LIBS += `pkg-config --libs gtk+-2.0` `pkg-config --libs gconf-2.0`
endif # DEBUG
endif # Linux

# FreeBSD: add the necessary libraries
ifeq ($(SUBARCH),freebsd)

LIBS += `sdl-config --libs` -lGL -lXinerama

# the new debugger relies on GTK+ in addition to the base SDLMAME needs
ifdef DEBUG
OSOBJS += $(OBJ)/sdl/debugwin.o $(OBJ)/sdl/dview.o $(OBJ)/sdl/debug-sup.o $(OBJ)/sdl/debug-intf.o
CFLAGS += `pkg-config --cflags gtk+-2.0` `pkg-config --cflags gconf-2.0` 
LIBS += `pkg-config --libs gtk+-2.0` `pkg-config --libs gconf-2.0`
else
CFLAGS += -I/usr/local/include -I/usr/X11R6/include
LIBS += -L/usr/X11R6/lib
endif # DEBUG
endif # FreeBSD

# Win32: add the necessary libraries
ifeq ($(SUBARCH),win32)
OSDCOREOBJS += $(OBJ)/$(MAMEOS)/main.o
LIBS += -lmingw32 -lSDL -lopengl32
endif	# Win32

# Mac OS X: add the necessary libraries
ifeq ($(SUBARCH),macosx)
OSOBJS += $(OBJ)/sdl/SDLMain_tmpl.o
LIBS += -framework SDL -framework Cocoa -framework OpenGL -lpthread 

# the new debugger relies on GTK+ in addition to the base SDLMAME needs
ifdef DEBUG
OSOBJS += $(OBJ)/sdl/debugosx.o
LIBS += -framework Carbon
endif	# DEBUG
endif	# Mac OS X

# drawSDL depends on the core software renderer, so make sure it exists
$(OBJ)/$(MAMEOS)/drawsdl.o : rendersw.c sdl/texcopy.c sdl/texsrc.h

# due to quirks of using /bin/sh, we need to explicitly specify the current path
CURPATH = ./

$(OBJ)/sdl/scale2x.o: sdl/scale2x.c sdl/effect_func.h sdl/scale2x_core.c sdl/texsrc.h
